@@ -40,7 +40,7 @@ meltt_validate.meltt = function(
 
     # Specify Matching events
     matches <- meltt_duplicates(object)
-    matches <- matches[,grepl("dataID|eventID",colnames(matches))]
+    matches <- matches[,grepl("dataset|event",colnames(matches))]
     cols <- (1:ncol(matches))[1:ncol(matches) %% 2 == 1]
     match_id <- matrix(nrow=nrow(matches),ncol=length(cols))
     for (c in 1:length(cols)) {
@@ -185,7 +185,7 @@ meltt_validate.meltt = function(
       })
     entries_info <- as.tibble(ldply(entries_info))
 
-    formatted <- apply(entries_info[,c(1:3)*-1],1,function(x){
+    formatted <- apply(entries_info[,(1:2)*-1],1,function(x){
       x = iconv(x, "latin1", "ASCII", sub="") # Remove any potential encoding issues
       paste0(paste(paste0("<b><i>",names(x),"</i></b>"),x,sep=": "),collapse = "<br/><br/>")
       # paste0(paste(names(x),x,sep=": "),collapse = "\n\n")
